@@ -12,6 +12,8 @@ metrics_eps = 10e-5
 metrics_num_precision = 5
 
 data_load_limit = _sys.maxsize
+data_split_ratio = [0.6, 0.2, 0.2]
+current_seed = _random.randint(0, 2**24)
 
 
 def boolean_string(s):
@@ -34,11 +36,12 @@ default_args = _ap.ArgumentParser()
 
 default_args.add_argument('-ph', '--phase', default=None, choices=['train', 'test'], type=str,
                           help='Can be train/test.')
-default_args.add_argument("-b", "--batch_size", default=32, type=int, help="Mini-batch size.")
-default_args.add_argument('-ep', '--epochs', default=21, type=int, help='Number of epochs.')
-default_args.add_argument('-ni', '--num_iteration', default=1, type=int, help='Number of iterations for gradient accumulation.')
+default_args.add_argument("-b", "--batch_size", default=4, type=int, help="Mini-batch size.")
+default_args.add_argument('-ep', '--epochs', default=31, type=int, help='Number of epochs.')
+default_args.add_argument('-ni', '--num_iteration', default=1, type=int,
+                          help='Number of iterations for gradient accumulation.')
 default_args.add_argument('-lr', '--learning_rate', default=0.001, type=float, help='Learning rate.')
-default_args.add_argument('-gpus', '--gpus', default=[0], nargs='*', type=int, help='How many gpus to use?')
+default_args.add_argument('-gpus', '--gpus', default=[0] if cuda_available else [], nargs='*', type=int, help='How many gpus to use?')
 default_args.add_argument('-pin', '--pin_memory', default=cuda_available, type=boolean_string, help='Pin Memory.')
 default_args.add_argument('-nw', '--num_workers', default=4, type=int,
                           help='Number of workers to work on data loading.')
@@ -49,12 +52,12 @@ default_args.add_argument('-pt', '--pretrained_path', default=None, type=str,
                           help='Full path to pretrained weights(It will be loaded before training.)')
 default_args.add_argument('-v', '--verbose', default=True, type=boolean_string,
                           help='Prints information on different steps.')
-default_args.add_argument('-s', '--seed', default=_random.randint(0, int(1e11)), type=int, help='Seed')
+default_args.add_argument('-seed', '--seed_all', default=False, type=boolean_string, help='Seed everything.')
 default_args.add_argument('-f', '--force', default=False, type=boolean_string, help='Force')
 default_args.add_argument('-pat', '--patience', default=11, type=int, help='Early Stopping patience epochs.')
 default_args.add_argument('-lsp', '--load_sparse', default=False, type=boolean_string, help='Load sparse dataset.')
 default_args.add_argument('-nf', '--num_folds', default=None, type=int, help='Number of folds.')
-default_args.add_argument('-rt', '--split_ratio', default=[0.6, 0.2, 0.2], nargs='*', type=float,
+default_args.add_argument('-spr', '--split_ratio', default=None, nargs='*', type=float,
                           help='Split ratio. Eg: 0.6 0.2 0.2 or 0.8 0.2. Exclusive to num_fold.')
 
 _known, _unknown = default_args.parse_known_args()
